@@ -86,8 +86,9 @@ class EncoderDecoderLM:
         logging.info(f'Loading Model: `{model}`')
 
         # load model
+        self.device_map = device_map
         self.tokenizer, self.model, self.config = get_lm(
-            model, use_auth_token=use_auth_token, torch_dtype=torch_dtype, device_map=device_map,
+            model, use_auth_token=use_auth_token, torch_dtype=torch_dtype, device_map=self.device_map,
             low_cpu_mem_usage=low_cpu_mem_usage, hf_cache_dir=hf_cache_dir)
         if self.tokenizer.pad_token is None:
             self.tokenizer.pad_token = "<<PAD>>"
@@ -107,14 +108,14 @@ class EncoderDecoderLM:
 
         # GPU setup
         self.device = self.model.device
-        if device_map is None:
+        if self.device_map is None:
             num_gpus = torch.cuda.device_count() if num_gpus is None else num_gpus
             if num_gpus == 1:
-                self.model.to('cuda')
+                self.model.cuda()
                 self.device = self.model.device
             elif num_gpus > 1:
                 self.model = torch.nn.DataParallel(self.model)
-                self.model.to('cuda')
+                self.model.cuda()
                 self.device = self.model.module.device
         self.model.eval()
         logging.info(f'\t * model is loaded on: {self.device}')
@@ -157,11 +158,17 @@ class EncoderDecoderLM:
                 # shift the label sequence for causal inference
                 label = output_encode["input_ids"]
                 label[label == self.tokenizer.pad_token_id] = PAD_TOKEN_LABEL_ID
-                model_inputs["labels"] = label.to(self.device)
+
+                if self.device_map is None:
+                    model_inputs["labels"] = label.to(self.device)
+                    output = self.model(**{k: v.to(self.device) for k, v in model_inputs.items()})
+                else:
+                    model_inputs["labels"] = label
+                    output = self.model(**{k: v.cuda() for k, v in model_inputs.items()})
+                    model_inputs["labels"] = label.to(self.device)
 
                 # model run & loss conversion into likelihood
                 valid_length = (model_inputs["labels"] != PAD_TOKEN_LABEL_ID).sum(dim=-1)
-                output = self.model(**{k: v.to(self.device) for k, v in model_inputs.items()})
                 loss = self.loss_fct(output['logits'].view(-1, self.config.vocab_size), model_inputs["labels"].view(-1))
                 loss = loss.view(len(output['logits']), -1)
                 loss = torch.sum(loss, -1) / valid_length
